﻿/**
 * @project Coveo for Sitecore
 * @Copyright (c) 2005-2018, Coveo Solutions Inc.
 */

/**
 * Determines whether the specified element is visible.
 * @param {Object} element - An element whose visibility must be determined.
 * @returns {boolean} true if the element is visible, false otherwise.
 */
function isElementVisible(element) {
    // This function is necessary because the visible() function of prototype.js
    // is not reliable enough. It becomes unusable if the 'display' attribute
    // is also set directly via CSS stylesheets.
    return element &&
           element.offsetWidth &&
           element.offsetHeight &&
           element.offsetWidth > 0 &&
           element.offsetHeight > 0;
}

/**
 * Toggles the visibility of the specified block element.
 * @param {Object} element - A block element whose visibility must be toggled.
 */
function toggleBlockElementVisibility(element) {
    // This function is necessary because prototype.js doesn't work
    // if the 'display' attribute is also set via CSS stylesheets.
    element.toggleClassName('disabled');
}